# :electric_plug:PyRPoint

Dual R & Python package to be used for creating PowerPoint charts and slides easily. Designed with business applications in mind

## Table of Contents

+ [Prerequisites](#prereq)
+ [Installation/Setup](#setup)
+ [Features](#features)
+ [Configuration](#config)
+ [API Reference](#api)
+ [Licensing](#license)


## <a name="prereq"></a>Prerequisites
+ [R](https://www.r-project.org/)
+ [RStudio](https://www.rstudio.com/products/rstudio/download/): Optional.
+ Python 3.7.5

## <a name="setup"></a>Installation/Setup

Checkout the Code 
  ```
  $ git clone https://github.com/AnthonyKenny98/PyRPoint.git
  $ cd PyRPoint
  ```
Copy src folder into your Python or R project.

More coming soon

### Install Dependencies

Coming soon


## <a name="features"></a>Features

Coming soon

## <a name="license"></a>Licensing

This project is licensed under the MIT License.  See the [LICENSE](LICENSE) file for more information.
